@@ -18,10 +18,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from .api import *
-from .direct import *
-from .exceptions import *
-from .result import *
-from .routing import *
-from .security import *
-from .types import *
+
+from .. import *
+
+
+from warnings import warn as _warn
+_warn("The 'neo4j.v1' package is deprecated, import from 'neo4j' instead", category=DeprecationWarning, stacklevel=2)
